import binascii
import json
import os


def test_colors():
    parent_dir = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
    color_files = os.listdir(parent_dir)
    assert len(color_files) > 1
    for color_file in color_files:
        if color_file.endswith('.json'):
            with open(os.path.join(parent_dir, color_file)) as file_:
                colors = json.load(file_)
            for color_name, rgb_value in colors.items():
                assert color_name[0].islower()
                for letter in color_name[1:]:
                    assert letter.islower() or letter.isdigit()
                assert rgb_value.startswith('#')
                assert len(rgb_value[1:]) in (3, 6)
                binascii.unhexlify(rgb_value[1:])



from setuptools import setup, find_packages

setup(
    name='color-names',
    version='1.1.2',
    url='http://github.com/bpeterso2000/color-names',
    keywords=[
        'color', 'colour', 'colors' 'colours', 'names', 'hex', 'css',
        'html', 'themes', 'styles', 'standards', 'ansi', '256', 'truecolor',
    ],

    author='Brian Peterson',
    author_email='bpeterso2000@yahoo.com',

    description='A curated collection of color names to RGB hex code mappings',

    packages=find_packages(include=['color-names']),
    include_package_data=True,
    zipsafe=False,

    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'License :: Public Domain',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
    ],

    test_requires=['pytest'],
)
